@@ -15,5 +15,5 @@ company1 = {
     "confirm_obs": False,
     "confirm_afs": False,
     "policy": "a3a6a312-5fb6-1ce8-bb8b-73192816e4c5",
-    "log_server_account": None
+    "log_server_account": None,
 }
