@@ -8,12 +8,13 @@ from pylogcabin.exceptions import (
     ConsoleAPIServerError,
     ConsoleAPINotFoundError,
 )
-from typing import Optional, TYPE_CHECKING
+from typing import TYPE_CHECKING
+
 if TYPE_CHECKING:
     from lcrequests.tokens import PasetoToken
     from lcrequests.typehints import Subject
 from .tokens import V4PasetoToken, UmbrellaTokenCentral
-from .typehints import DELETE, GET, HEAD, PATCH, POST, PUT
+from .typehints import HTTP_VERBS
 
 
 class UmbrellaAPI:
@@ -28,6 +29,7 @@ class UmbrellaAPI:
     results = api.get()
     print(results.json())
     """
+
     API_NAME: str
     SERVER: str
     TOKEN_CLASS: V4PasetoToken
@@ -36,7 +38,7 @@ class UmbrellaAPI:
         self,
         signed_token_class: 'PasetoToken',
         timeout: int = 30,
-        headers: Optional[dict] = None,
+        headers: dict | None = None,
     ):
         """
         :param signed_token_class: Token object for authenticating
@@ -70,7 +72,7 @@ class UmbrellaAPI:
         self.url = f'{self.base_url}/{subject_path}'
         return self.url
 
-    def get_url(self, cid: str = '', params: dict = None) -> str:
+    def get_url(self, cid: str = '', params: dict | None = None) -> str:
         """
         Generate path params, supporting custom API routes, such as
         /ksync/syncbatch/<cid>/run/
@@ -89,7 +91,7 @@ class UmbrellaAPI:
 
         return f'{url}?{urlencode(params)}'
 
-    def http_request(self, verb: str, url: str, post_data: dict = None) -> Response:
+    def http_request(self, verb: HTTP_VERBS, url: str, post_data: dict | None = None) -> Response:
         """Make an HTTP request to the Umbrella Console.
 
         :param verb: The HTTP method to call ('get', 'post', 'put', 'delete')
@@ -98,7 +100,7 @@ class UmbrellaAPI:
 
         Returns a request result object.
         """
-        if verb in (PATCH, POST, PUT):
+        if verb in ('PATCH', 'POST', 'PUT'):
             headers = {'Content-Type': 'application/x-www-form-urlencoded'}
         else:
             headers = {}
@@ -128,7 +130,7 @@ class UmbrellaAPI:
 
             if response.status == 404:
                 # Return response for HEAD existence requests checks as 404 will be expected
-                if verb == HEAD:
+                if verb == 'HEAD':
                     return response
 
                 raise ConsoleAPINotFoundError(f'{url} not found', response=response)
@@ -143,7 +145,7 @@ class UmbrellaAPI:
 
         return response
 
-    def head(self, cid: str = '', params: dict = None, **kwargs):
+    def head(self, cid: str = '', params: dict | None = None, **kwargs):
         """Make a HEAD request to the Umbrella server.
 
         :param params: Data to send as query parameters
@@ -153,11 +155,11 @@ class UmbrellaAPI:
         Returns the response received from the server.
         """
         return self.http_request(
-            verb=HEAD,
+            verb='HEAD',
             url=self.get_url(cid=cid, params=params),
         )
 
-    def get(self, cid: str = '', params: dict = None, **kwargs):
+    def get(self, cid: str = '', params: dict | None = None, **kwargs):
         """Make a GET request to the Umbrella server.
 
         :param params: Data to send as query parameters
@@ -167,11 +169,17 @@ class UmbrellaAPI:
         Returns the response received from the server.
         """
         return self.http_request(
-            verb=GET,
+            verb='GET',
             url=self.get_url(cid=cid, params=params),
         )
 
-    def post(self, cid: str = '', params: dict = None, post_data: dict = None, **kwargs):
+    def post(
+        self,
+        cid: str = '',
+        params: dict | None = None,
+        post_data: dict | None = None,
+        **kwargs,
+    ):
         """Make a POST request to the Umbrella Console.
 
         :param cid: Canonical ID of record to retrieve
@@ -181,7 +189,7 @@ class UmbrellaAPI:
         Returns the response received from the server.
         """
         return self.http_request(
-            verb=POST,
+            verb='POST',
             url=self.get_url(cid=cid, params=params),
             post_data=post_data,
         )
@@ -192,7 +200,7 @@ class UmbrellaAPI:
         :param cid: Canonical ID of record to retrieve
         """
         return self.http_request(
-            verb=DELETE,
+            verb='DELETE',
             url=self.get_url(cid=cid),
         )
 
